@@ -29,9 +29,6 @@ INTERNALERROR = 'InternalError'
 # Cmq 接口调用失败。
 INTERNALERROR_CALLCMQERROR = 'InternalError.CallCmqError'
 
-# Cns 接口调用失败。
-INTERNALERROR_CALLCNSERROR = 'InternalError.CallCnsError'
-
 # 内部接口调用失败。
 INTERNALERROR_CALLERROR = 'InternalError.CallError'
 
@@ -56,6 +53,9 @@ INTERNALERROR_CALLTVPCERROR = 'InternalError.CallTvpcError'
 # VPC接口调用失败。
 INTERNALERROR_CALLVPCERROR = 'InternalError.CallVpcError'
 
+# 调用其他服务异常。
+INTERNALERROR_CALLEEERROR = 'InternalError.CalleeError'
+
 # 内部请求错误。
 INTERNALERROR_REQUESTERROR = 'InternalError.RequestError'
 
@@ -365,6 +365,12 @@ RESOURCENOTFOUND_SCALINGPOLICYNOTFOUND = 'ResourceNotFound.ScalingPolicyNotFound
 # 指定的定时任务不存在。
 RESOURCENOTFOUND_SCHEDULEDACTIONNOTFOUND = 'ResourceNotFound.ScheduledActionNotFound'
 
+# TDMQ-CMQ 队列不存在。
+RESOURCENOTFOUND_TDMQCMQQUEUENOTFOUND = 'ResourceNotFound.TDMQCMQQueueNotFound'
+
+# TDMQ-CMQ 主题不存在。
+RESOURCENOTFOUND_TDMQCMQTOPICNOTFOUND = 'ResourceNotFound.TDMQCMQTopicNotFound'
+
 # 伸缩组状态异常。
 RESOURCEUNAVAILABLE_AUTOSCALINGGROUPABNORMALSTATUS = 'ResourceUnavailable.AutoScalingGroupAbnormalStatus'
 
@@ -410,5 +416,8 @@ RESOURCEUNAVAILABLE_PROJECTINCONSISTENT = 'ResourceUnavailable.ProjectInconsiste
 # 关机实例不允许添加到伸缩组。
 RESOURCEUNAVAILABLE_STOPPEDINSTANCENOTALLOWATTACH = 'ResourceUnavailable.StoppedInstanceNotAllowAttach'
 
+# TDMQ-CMQ 主题无订阅者。
+RESOURCEUNAVAILABLE_TDMQCMQTOPICHASNOSUBSCRIBER = 'ResourceUnavailable.TDMQCMQTopicHasNoSubscriber'
+
 # 指定的可用区不可用。
 RESOURCEUNAVAILABLE_ZONEUNAVAILABLE = 'ResourceUnavailable.ZoneUnavailable'
